Documentation
¶
Overview ¶
Package normalization validates and canonicalizes user-provided domain names.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Error ¶
type Error struct {
// Tag is the stable normalization error code.
Tag string
// Params contains interpolation values for the error message template.
Params map[string]string
}
Error represents one domain-normalization validation issue.
func NormalizeLabel ¶
NormalizeLabel normalizes a single label and returns errors and the A-label.
func NormalizeName ¶
NormalizeName normalizes a domain name and returns errors and the normalized name.
Click to show internal directories.
Click to hide internal directories.